#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
A simple Last.fm scrobbler for MPD.
"""

__version__ = "0.3.1"

name = "mpdscrobble"
